'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = fetchDispatch;

var _isomorphicFetch = require('isomorphic-fetch');

var _isomorphicFetch2 = _interopRequireDefault(_isomorphicFetch);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function fetchDispatch(url) {
	var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
	var actions = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

	// If there are only two parameters, the second one is actions
	if (actions === {}) {
		actions = options;
		options = undefined;
	}

	return function (dispatch) {

		if (typeof actions.request === 'function') {
			actions.request();
		}

		return (0, _isomorphicFetch2.default)(url, options).then(function (response) {
			if (response.status.toString().charAt(0) === '2') {
				return response.json();
			} else if (response.status.toString().charAt(0) === '4') {
				throw response.json();
			}
		}).then(function (json) {
			if (typeof actions.success === 'function') {
				dispatch(actions.success(json));
			}
			return json;
		}).catch(function (err) {
			if (typeof actions.fail === 'function') {
				dispatch(actions.fail(err));
			}
			return err;
		});
	};
}